%define subrel 1
Name:		dropbear
Version:	2022.83
Release:	%mkrel 2
Summary:	SSH2 server and client

Group:		Networking/Remote access
License:	MIT
URL:		https://matt.ucc.asn.au/dropbear/dropbear.html
Source0:	https://matt.ucc.asn.au/dropbear/releases/%{name}-%{version}.tar.bz2
Source1:	dropbear.service
Source2:	dropbear-keygen.service
Patch0:		dropbear-2018.76-mga-binpaths.patch
Patch1:		dropbear-2018.80-mga-enable-x11.patch
Patch2:		dropbear-2020.83-mga-enable-aesgcm.patch

# CVE-2023-48795
# mga#32641
Patch3:		6e43be5c7b99dbee49dc72b6f989f29fdd7e9356.patch

BuildRequires:	pkgconfig(zlib)
BuildRequires:	tomcrypt-devel >= 1.18.2-5
BuildRequires:	pkgconfig(libtommath)
# (cg) I tried enabling pam but it seems somewhat broken and doesn't
# register with systemd-logind for now. Should be fixed.
# https://bugzilla.redhat.com/show_bug.cgi?id=770251
#BuildRequires:	libpam-devel
Requires(post):		rpm-helper >= 0.24.8-1
Requires(preun):	rpm-helper >= 0.24.8-1

Requires:	initscripts
Requires(post):	chkconfig >= 0.9, initscripts
# This is only needed for sftp support
Recommends:	openssh-server

%description
Dropbear is a relatively small SSH 2 server and client.  Dropbear
is particularly useful for "embedded"-type Linux (or other Unix)
systems, such as wireless routers. SFTP support requires the
openssh-server package.

%prep
%autosetup -p1

%build
# Point to the OpenSSH SFTP subsystem binary since dropbear doesn't include
# sftp support itself. The location is architecture-dependent, so must be
# overridden at build time, not patch time.
%configure CPPFLAGS='-DSFTPSERVER_PATH=\"%{_libdir}/ssh/sftp-server\"'
# --enable-pam
%make_build

%install
%make_install
install -d %{buildroot}%{_sysconfdir}/dropbear
install -d %{buildroot}%{_unitdir}
install -m 0644 %{SOURCE1} %{buildroot}%{_unitdir}/dropbear.service
install -m 0644 %{SOURCE2} %{buildroot}%{_unitdir}/dropbear-keygen.service

chmod a+r CHANGES INSTALL LICENSE MULTI README SMALL

%post
%_post_service %{name}

%preun
%_preun_service %{name}

%files
%doc CHANGES INSTALL LICENSE MULTI README SMALL
%dir %{_sysconfdir}/dropbear
%{_unitdir}/dropbear*
%{_bindir}/dropbearkey
%{_bindir}/dropbearconvert
%{_bindir}/dbclient
%{_sbindir}/dropbear
%{_mandir}/man1/dbclient.1*
%{_mandir}/man1/dropbearconvert.1*
%{_mandir}/man1/dropbearkey.1*
%{_mandir}/man8/dropbear.8*


%changelog
* Wed Dec 27 2023 papoteur <papoteur> 2022.83-2.1.mga9
+ Revision: 2022317
- add patch for CVE-2023-48795

* Fri Dec 23 2022 danf <danf> 2022.83-2.mga9
+ Revision: 1926152
- Enable AES-GCM cipher for wider compatibility & security

* Tue Nov 15 2022 danf <danf> 2022.83-1.mga9
+ Revision: 1907396
- Upgrade to 2022.83
- Includes fix for CVE-2021-36369

* Sat Apr 02 2022 umeabot <umeabot> 2020.81-3.mga9
+ Revision: 1840401
- Mageia 9 Mass Rebuild
+ danf <danf>
- Change PIDFile to use new path

* Sat Jun 12 2021 wally <wally> 2020.81-2.mga9
+ Revision: 1730479
- rebuild with relocated libtomcrypt headers

* Wed Dec 09 2020 danf <danf> 2020.81-1.mga8
+ Revision: 1654989
- Upgrade to 2020.81
- Reenable X11 support which (disabled by default in 2020.80)

* Mon Oct 12 2020 danf <danf> 2020.80-1.mga8
+ Revision: 1634725
- Upgraded to 2020.80

* Wed Apr 15 2020 danf <danf> 2019.78-1.mga8
+ Revision: 1567660
- Upgraded to 2019.78

* Fri Feb 14 2020 umeabot <umeabot> 2018.76-3.mga8
+ Revision: 1521897
- Mageia 8 Mass Rebuild
+ wally <wally>
- replace deprecated %%configure2_5x
- replace deprecated %%makeinstall_std

* Fri Jan 04 2019 danf <danf> 2018.76-2.mga7
+ Revision: 1349097
- Added upstream patch for CVE-2018-15599

* Fri Jan 04 2019 danf <danf> 2018.76-1.mga7
+ Revision: 1349086
- Upgraded to 2018.76
- Includes Spectre security mitigations

* Sun Sep 23 2018 umeabot <umeabot> 2017.75-3.mga7
+ Revision: 1297511
- Mageia 7 Mass Rebuild

* Sun Jan 28 2018 danf <danf> 2017.75-2.mga7
+ Revision: 1197591
- Rebuild for new libtomcrypt

* Tue May 23 2017 danf <danf> 2017.75-1.mga6
+ Revision: 1104298
- Upgraded to 2017.75
- fixes CVE-2017-9078 and CVE-2017-9079 (bug #20901)

* Wed Aug 10 2016 luigiwalser <luigiwalser> 2016.74-1.mga6
+ Revision: 1045267
- 2016.74

* Fri May 13 2016 danf <danf> 2016.73-1.mga6
+ Revision: 1014573
- Upgraded to 2016.73

* Sat Apr 09 2016 philippem <philippem> 2016.72-2.mga6
+ Revision: 999870
- rebuild for new libtommath

* Fri Mar 11 2016 danf <danf> 2016.72-1.mga6
+ Revision: 989314
- Upgraded to 2016.72
 - fixes CVE-2016-3116

* Sat Jan 02 2016 danf <danf> 2015.71-1.mga6
+ Revision: 918319
- Update to 2015.71

* Sun Aug 23 2015 danf <danf> 2015.68-1.mga6
+ Revision: 868236
- Updated to ver. 2015.68

* Sun Jun 21 2015 danf <danf> 2015.67-1.mga6
+ Revision: 837748
- Updated to ver. 2015.67

* Wed Nov 05 2014 danf <danf> 2014.66-1.mga5
+ Revision: 795872
- Update to 2014.66 (bugfix release)

* Wed Oct 15 2014 umeabot <umeabot> 2014.65-4.mga5
+ Revision: 750973
- Second Mageia 5 Mass Rebuild

* Sun Oct 05 2014 danf <danf> 2014.65-3.mga5
+ Revision: 736930
- Use system-provided libtommath and libtomcrypto (mga#11036)

* Tue Sep 16 2014 umeabot <umeabot> 2014.65-2.mga5
+ Revision: 678863
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Wed Sep 03 2014 danf <danf> 2014.65-1.mga5
+ Revision: 671153
- Upgraded to version 2014.65. Major changes include:
  - The -K keepalive option now behaves more like OpenSSH's ServerAliveInterval
  - Rework TCP priority setting.
  - Numerous bug fixes
- Added syslog as a prerequisite for startup by systemd
- Added to RSA and DSS the generation of an ECDSA host key on first startup

* Sat May 17 2014 danf <danf> 2014.63-1.mga5
+ Revision: 623123
- Upgraded to 2014.63.  Major changes since 2013.59 include:
- added ECC (elliptic curve) support
- fixed some hangs and crashes
- changed port separator syntax to host^port
- ensure that generated RSA keys are always exactly the length requested

* Mon Oct 21 2013 umeabot <umeabot> 2013.59-2.mga4
+ Revision: 539203
- Mageia 4 Mass Rebuild
+ danf <danf>
- Dropped the obsolete SysV init script (mga#11458)
- Stop converting CHANGES now that it's natively UTF-8

* Fri Oct 04 2013 danf <danf> 2013.59-1.mga4
+ Revision: 491610
- upgraded to 2013.59 bug fix release
- removed glibc217-crypt.patch (merged upstream)

* Thu Aug 22 2013 luigiwalser <luigiwalser> 2013.58-2.mga4
+ Revision: 469235
- add patch from mancha to fix null pointer deref with glibc 2.17

* Wed Jul 03 2013 danf <danf> 2013.58-1.mga4
+ Revision: 449862
- upgraded to 2013.58; many bug fixes, improved entropy gathering, new HMAC
  algorithms, decreased connection setup time, etc.
- using pkgconfig style BuildRequires

* Tue Jul 02 2013 danf <danf> 2012.55-5.mga4
+ Revision: 449629
- added binpaths.patch to fix sftp and X11 forwarding
- remove /bin from the default PATH, since it's unnecessary with usrmove
- removed %%clean section

* Fri Jan 11 2013 umeabot <umeabot> 2012.55-4.mga3
+ Revision: 349115
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Sat Apr 28 2012 tmb <tmb> 2012.55-3.mga2
+ Revision: 233679
- Require rpm-helper >= 0.24.8-1 for systemd support
- rebuild for versioned rpm-helper requires

* Sun Apr 22 2012 colin <colin> 2012.55-1.mga2
+ Revision: 232534
- New version: 2012.55 (CVE-2012-0920)
- Add systemd support (PAM registration is broken)
- Adapt spec to Mageia

* Mon Apr 25 2011 stormi <stormi> 0.53.1-2.mga1
+ Revision: 90810
- fix RPM group

* Mon Apr 25 2011 tmb <tmb> 0.53.1-1.mga1
+ Revision: 90190
- imported package dropbear


* Sun Apr 24 2011 Thomas Backlund <tmb@mageia.org> 0.53.1-1.mga1
- update to 0.53.1

* Tue Feb 08 2011 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.52-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_15_Mass_Rebuild

* Mon Apr 19 2010 Itamar Reis Peixoto <itamar@ispbrasil.com.br> - 0.52-1
- New version 0.5.2

* Fri Jul 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.50-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_12_Mass_Rebuild

* Tue Feb 24 2009 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.50-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_11_Mass_Rebuild

* Mon Feb 18 2008 Fedora Release Engineering <rel-eng@fedoraproject.org> - 0.50-3
- Autorebuild for GCC 4.3

* Mon Jan 10 2008 Lennert Buytenhek <buytenh@wantstofly.org> - 0.50-2
- Incorporate changes from Fedora package review:
  - Use full URL for Source0.
  - Ship dropbear.init with mode 0644 in the SRPM.
  - Convert CHANGES to utf-8 in %%setup, as the version shipped with
    dropbear 0.50 isn't utf-8 clean (it's in iso-8859-1.)
  - Add a reload entry to the init script, and don't enable the
    service by default.

* Mon Jan  7 2008 Lennert Buytenhek <buytenh@wantstofly.org> - 0.50-1
- Update to 0.50.
- Add init script.

* Fri Aug  3 2007 Lennert Buytenhek <buytenh@wantstofly.org> - 0.49-1
- Initial packaging.
